@@ -1,12 +1,41 @@
+/*******************************************************************************
+ *
+ * MIT License
+ *
+ * Copyright (c) 2025 Advanced Micro Devices, Inc.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in all
+ * copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ *
+ *******************************************************************************/
 #ifndef GUARD_MIOPEN_LSTM_VERIFY_GEMM_HPP
 #define GUARD_MIOPEN_LSTM_VERIFY_GEMM_HPP
 
 #define ADNN_MM_TRANSPOSE 1
 
-#include <math.h>
-#include <cassert>
-#include <algorithm>
 #include "dropout_gpu_emulator.hpp"
+#include "mloConvHost.hpp" // ADNN_mm_cpu
+
+#include <../test/rnn_util.hpp>
+
+#include <algorithm>
+#include <cassert>
+#include <math.h>
 
 template <typename Tgpu, typename Tref>
 void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
@@ -38,10 +67,10 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                                  bool hx_is_null = false,
                                  bool cx_is_null = false)
 {
-    int batch_n = sumvc(in_n);
+    size_t batch_n = sumvc(in_n);
 
     int numlayer = bidirection ? hy_d / 2 : hy_d;
-    int bacc, baccbi; // accumulation of batch
+    size_t bacc, baccbi; // accumulation of batch
     int bi = bidirection ? 2 : 1;
 
     int in_stride  = in_h;
@@ -106,7 +135,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
     }
 
     // initial dropoput
-    std::vector<prngStates> dropout_states_host;
+    std::vector<rocrand_state_xorwow> dropout_states_host;
     std::vector<unsigned char> dropout_reservespace_host;
     std::vector<Tref> dropout_hid_state;
     miopenTensorDescriptor_t dropout_inputTensor{}, dropout_outputTensor{};
@@ -114,8 +143,8 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
     {
         size_t statesSizeInBytes = 0;
         miopenDropoutGetStatesSize(handle, &statesSizeInBytes);
-        size_t states_size  = statesSizeInBytes / sizeof(prngStates);
-        dropout_states_host = std::vector<prngStates>(states_size);
+        size_t states_size  = statesSizeInBytes / sizeof(rocrand_state_xorwow);
+        dropout_states_host = std::vector<rocrand_state_xorwow>(states_size);
         InitKernelStateEmulator(dropout_states_host, dropoutDesc);
 
         std::array<int, 2> drop_in_len  = {{batch_n, hy_h * bi}};
@@ -141,8 +170,8 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
     // forward emulator
     for(int li = 0; li < numlayer; li++)
     {
-        int hid_shift = li * batch_n * hy_stride;
-        int hx_shift  = li * in_n.at(0) * h_stride;
+        size_t hid_shift = li * batch_n * hy_stride;
+        size_t hx_shift  = li * in_n.at(0) * h_stride;
 
         // from input
         if(li == 0)
@@ -215,8 +244,9 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
         }
         else
         {
-            int wei_shift = (in_h + hy_h) * wei_stride + (li - 1) * (bi * hy_h + hy_h) * wei_stride;
-            int prelayer_shift = (li - 1) * batch_n * hy_stride + bi * 5 * hy_h;
+            size_t wei_shift =
+                (in_h + hy_h) * wei_stride + (li - 1) * (bi * hy_h + hy_h) * wei_stride;
+            size_t prelayer_shift = (li - 1) * batch_n * hy_stride + bi * 5 * hy_h;
             if(use_dropout)
             {
                 auto dropout_states_tmp = dropout_states_host;
@@ -260,7 +290,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
             // from bias
             if(biased)
             {
-                int wei_shift_bias_temp = wei_shift_bias + li * 2 * wei_stride;
+                size_t wei_shift_bias_temp = wei_shift_bias + li * 2 * wei_stride;
 
                 for(int bs = 0; bs < batch_n; bs++)
                 {
@@ -279,7 +309,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
         for(int ti = 0; ti < seqLength; ti++)
         {
             baccbi -= in_n.at(seqLength - 1 - ti);
-            int wei_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
+            size_t wei_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
 
             if(ti == 0)
             {
@@ -306,7 +336,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                     // from bias
                     if(biased)
                     {
-                        int wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
+                        size_t wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
 
                         for(int bs = 0; bs < in_n[ti]; bs++)
                         {
@@ -379,7 +409,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                 // from bias
                 if(biased)
                 {
-                    int wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
+                    size_t wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
 
                     for(int bs = 0; bs < in_n[ti]; bs++)
                     {
@@ -419,7 +449,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                         // from bias
                         if(biased)
                         {
-                            int wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
+                            size_t wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
 
                             for(int bs = in_n.at(seqLength - ti); bs < in_n.at(seqLength - 1 - ti);
                                 bs++)
@@ -455,7 +485,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                     // from bias
                     if(biased)
                     {
-                        int wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
+                        size_t wei_shift_bias_temp = wei_shift_bias + (li * 2 + 1) * wei_stride;
 
                         for(int bs = 0; bs < in_n.at(seqLength - ti); bs++)
                         {
@@ -491,8 +521,8 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
                     }
                     else
                     {
-                        int prec_shift = li * batch_n * hy_stride +
-                                         (bacc - in_n.at(ti - 1)) * hy_stride + bi * 4 * hy_h;
+                        size_t prec_shift = li * batch_n * hy_stride +
+                                            (bacc - in_n.at(ti - 1)) * hy_stride + bi * 4 * hy_h;
 
                         hid_state.at(hid_shift + (bacc + bs) * hy_stride + bi * 4 * hy_h + h) +=
                             activfunc(hid_state.at(hid_shift + (bacc + bs) * hy_stride + hy_h + h),
@@ -579,7 +609,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
 
                             if(bs < in_n.at(seqLength - ti))
                             {
-                                int prec_shift =
+                                size_t prec_shift =
                                     li * batch_n * hy_stride +
                                     (baccbi + in_n.at(seqLength - 1 - ti)) * hy_stride +
                                     bi * 4 * hy_h + hy_h;
@@ -641,7 +671,7 @@ void RunLSTMForwardGEMMCPUVerify(miopenHandle_t handle,
     }
 
     // output
-    int prelayer_shift = (numlayer - 1) * batch_n * hy_stride + bi * 5 * hy_h;
+    size_t prelayer_shift = (numlayer - 1) * batch_n * hy_stride + bi * 5 * hy_h;
 
     for(int i = 0; i < numlayer * batch_n * hy_stride * 2; i++)
     {
@@ -711,10 +741,10 @@ void RunLSTMBackwardDataGEMMCPUVerify(
     bool dhy_is_null = false,
     bool dcy_is_null = false)
 {
-    int batch_n = sumvc(in_n);
+    size_t batch_n = sumvc(in_n);
 
     int numlayer = bidirection ? hy_d / 2 : hy_d;
-    int bacc, baccbi; // accumulation of batch
+    size_t bacc, baccbi; // accumulation of batch
     int bi = bidirection ? 2 : 1;
 
     int in_stride  = in_h;
@@ -816,9 +846,9 @@ void RunLSTMBackwardDataGEMMCPUVerify(
     // bwd data emulator
     for(int li = numlayer - 1; li >= 0; li--)
     {
-        int wei_shift = (in_h + hy_h) * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
-        int hid_shift = li * batch_n * hy_stride;
-        int hx_shift  = li * in_n[0] * h_stride;
+        size_t wei_shift = (in_h + hy_h) * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
+        size_t hid_shift = li * batch_n * hy_stride;
+        size_t hx_shift  = li * in_n[0] * h_stride;
 
         if(li == numlayer - 1)
         {
@@ -833,7 +863,7 @@ void RunLSTMBackwardDataGEMMCPUVerify(
         }
         else
         {
-            int prelayer_shift = (li + 1) * batch_n * hy_stride;
+            size_t prelayer_shift = (li + 1) * batch_n * hy_stride;
 
             ADNN_mm_cpu<Tref>(&dh_state[prelayer_shift],
                               hy_h * bi * 4,
@@ -942,8 +972,8 @@ void RunLSTMBackwardDataGEMMCPUVerify(
                     }
                 }
 
-                int pretime_shift = li * batch_n * hy_stride + (bacc + in_n[ti]) * hy_stride;
-                int weitime_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
+                size_t pretime_shift = li * batch_n * hy_stride + (bacc + in_n[ti]) * hy_stride;
+                size_t weitime_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
 
                 ADNN_mm_cpu<Tref>(&dh_state[pretime_shift],
                                   hy_h * 4,
@@ -999,7 +1029,7 @@ void RunLSTMBackwardDataGEMMCPUVerify(
                     {
                         if(bs < in_n[ti + 1])
                         {
-                            int pretime_shift =
+                            size_t pretime_shift =
                                 li * batch_n * hy_stride + (bacc + in_n[ti]) * hy_stride;
 
                             dh_state[hid_shift + (bacc + bs) * hy_stride + bi * 4 * hy_h + h] +=
@@ -1030,7 +1060,7 @@ void RunLSTMBackwardDataGEMMCPUVerify(
                     }
                     else
                     {
-                        int pretime_shift =
+                        size_t pretime_shift =
                             li * batch_n * hy_stride + (bacc - in_n[ti - 1]) * hy_stride;
 
                         dh_state[hid_shift + (bacc + bs) * hy_stride + hy_h + h] +=
@@ -1067,8 +1097,8 @@ void RunLSTMBackwardDataGEMMCPUVerify(
                     {
                         if(ti < seqLength - 1)
                         {
-                            int pretime_shift = li * batch_n * hy_stride +
-                                                (baccbi - in_n[seqLength - 2 - ti]) * hy_stride;
+                            size_t pretime_shift = li * batch_n * hy_stride +
+                                                   (baccbi - in_n[seqLength - 2 - ti]) * hy_stride;
 
                             dh_state[hid_shift + (baccbi + bs) * hy_stride + bi * 4 * hy_h + hy_h +
                                      h] +=
@@ -1121,8 +1151,9 @@ void RunLSTMBackwardDataGEMMCPUVerify(
 
                             if(bs < in_n[seqLength - ti])
                             {
-                                int pretime_shift = li * batch_n * hy_stride +
-                                                    (baccbi + in_n[seqLength - 1 - ti]) * hy_stride;
+                                size_t pretime_shift =
+                                    li * batch_n * hy_stride +
+                                    (baccbi + in_n[seqLength - 1 - ti]) * hy_stride;
 
                                 dh_state[hid_shift + (baccbi + bs) * hy_stride + 5 * hy_h + h] +=
                                     dh_state[hid_shift + (baccbi + bs) * hy_stride + bi * 4 * hy_h +
@@ -1170,8 +1201,8 @@ void RunLSTMBackwardDataGEMMCPUVerify(
         }
 
         // dcx, dhx
-        int pretime_shift = li * batch_n * hy_stride;
-        int weitime_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
+        size_t pretime_shift = li * batch_n * hy_stride;
+        size_t weitime_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
 
         ADNN_mm_cpu<Tref>(&dh_state[pretime_shift],
                           hy_h * 4,
@@ -1335,9 +1366,9 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
                                         bool use_dropout,
                                         bool hx_is_null = false)
 {
-    int batch_n  = sumvc(in_n);
-    int numlayer = bidirection ? hy_d / 2 : hy_d;
-    int bacc; // accumulation of batch
+    size_t batch_n = sumvc(in_n);
+    int numlayer   = bidirection ? hy_d / 2 : hy_d;
+    size_t bacc; // accumulation of batch
     int bi = bidirection ? 2 : 1;
 
     int in_stride  = in_h;
@@ -1398,8 +1429,8 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
         in_h = 0;
     }
 
-    int wei_shift_bias = (in_h + hy_h + (bi * hy_h + hy_h) * (numlayer - 1)) * wei_stride;
-    int wei_len        = wei_shift_bias;
+    size_t wei_shift_bias = (in_h + hy_h + (bi * hy_h + hy_h) * (numlayer - 1)) * wei_stride;
+    int wei_len           = wei_shift_bias;
     if(biased)
     {
         int in_bias = 2;
@@ -1449,11 +1480,12 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
         }
         else
         {
-            int prelayer_shift =
+            size_t prelayer_shift =
                 use_dropout ? 2 * numlayer * batch_n * hy_stride + (li - 1) * batch_n * hy_h * bi
                             : (li - 1) * batch_n * hy_stride + bi * hy_h * 5;
-            int hid_shift = li * batch_n * hy_stride;
-            int wei_shift = (in_h + hy_h) * wei_stride + (li - 1) * (bi * hy_h + hy_h) * wei_stride;
+            size_t hid_shift = li * batch_n * hy_stride;
+            size_t wei_shift =
+                (in_h + hy_h) * wei_stride + (li - 1) * (bi * hy_h + hy_h) * wei_stride;
 
             ADNN_mm_cpu<Tref>(&wkspace_state[hid_shift],
                               hy_h * bi * 4,
@@ -1491,9 +1523,9 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
         bacc = 0;
         for(int ti = 0; ti < seqLength; ti++)
         {
-            int hid_shift = li * batch_n * hy_stride + bacc * hy_stride;
-            int hx_shift  = li * in_n[0] * h_stride;
-            int wei_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
+            size_t hid_shift = li * batch_n * hy_stride + bacc * hy_stride;
+            size_t hx_shift  = li * in_n[0] * h_stride;
+            size_t wei_shift = in_h * wei_stride + li * (bi * hy_h + hy_h) * wei_stride;
             int pretime_shift;
 
             // between time
@@ -1521,7 +1553,7 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
 
                     if(biased)
                     {
-                        int bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
+                        size_t bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
 
                         for(int h = 0; h < hy_h * 4; h++)
                         {
@@ -1559,7 +1591,7 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
 
                 if(biased)
                 {
-                    int bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
+                    size_t bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
 
                     for(int h = 0; h < hy_h * 4; h++)
                     {
@@ -1598,7 +1630,7 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
 
                         if(biased)
                         {
-                            int bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
+                            size_t bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
 
                             for(int h = 0; h < hy_h * 4; h++)
                             {
@@ -1636,7 +1668,7 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
 
                         if(biased)
                         {
-                            int bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
+                            size_t bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
 
                             for(int h = 0; h < hy_h * 4; h++)
                             {
@@ -1672,7 +1704,7 @@ void RunLSTMBackwardWeightGEMMCPUVerify(std::vector<Tgpu>& in,
 
                     if(biased)
                     {
-                        int bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
+                        size_t bias_shift = wei_shift_bias + li * 2 * wei_stride + wei_stride;
 
                         for(int h = 0; h < hy_h * 4; h++)
                         {
