@@ -26,6 +26,7 @@
 #include "driver.hpp"
 #include "registry_driver_maker.hpp"
 
+#include "sys_info.hpp"
 #include <miopen/config.h>
 #include <miopen/stringutils.hpp>
 
@@ -80,6 +81,16 @@ int main(int argc, char* argv[])
         return rc;
     }
 
+    if(drv->GetInputFlags().GetValueInt("time") == 1)
+    {
+        // Print system information for ROCmPerf analysis.
+        // The ROCmPerf is a performance analysis tool based on MIOpenDirver logs.
+        size_t major, minor, patch;
+        miopenGetVersion(&major, &minor, &patch);
+        RocmPerf::SysInfo sysInfo(major, minor, patch);
+        sysInfo.ShowSysInfo();
+    }
+
     int fargval =
         !(miopen::StartsWith(base_arg, "CBAInfer") || miopen::StartsWith(base_arg, "CAInfer"))
             ? drv->GetInputFlags().GetValueInt("forw")
