@@ -32,6 +32,7 @@
 #include <miopen/fusion.hpp>
 #include <miopen/fusion_plan.hpp>
 #include <miopen/errors.hpp>
+#include <miopen/handle.hpp>
 #include <miopen/logger.hpp>
 #include <miopen/tensor.hpp>
 
@@ -45,8 +46,8 @@ extern "C" miopenStatus_t miopenCreateFusionPlan(miopenFusionPlanDescriptor_t* f
 {
     MIOPEN_LOG_FUNCTION(fusePlanDesc, fuseDirection, inputDesc);
     return miopen::try_([&] {
-        miopen::deref(fusePlanDesc) =
-            new miopen::FusionPlanDescriptor(fuseDirection, miopen::deref(inputDesc));
+        auto& desc = miopen::deref(fusePlanDesc);
+        desc       = new miopen::FusionPlanDescriptor(fuseDirection, miopen::deref(inputDesc));
     });
 }
 
@@ -236,7 +237,10 @@ extern "C" miopenStatus_t miopenCreateOpBatchNormBackward(miopenFusionPlanDescri
 extern "C" miopenStatus_t miopenCreateOperatorArgs(miopenOperatorArgs_t* args)
 {
     MIOPEN_LOG_FUNCTION(args);
-    return miopen::try_([&] { miopen::deref(args) = new miopen::OperatorArgs(); });
+    return miopen::try_([&] {
+        auto& theArgs = miopen::deref(args);
+        theArgs       = new miopen::OperatorArgs();
+    });
 }
 
 extern "C" miopenStatus_t miopenDestroyOperatorArgs(miopenOperatorArgs_t args)
@@ -421,6 +425,38 @@ extern "C" miopenStatus_t miopenSetOpArgsBatchNormBackward(miopenOperatorArgs_t
 }
 //---
 
+extern "C" miopenStatus_t
+miopenExecuteFusionPlan_v2(const miopenHandle_t handle,
+                           const miopenFusionPlanDescriptor_t fusePlanDesc,
+                           const miopenTensorDescriptor_t inputDesc,
+                           const void* input,
+                           const miopenTensorDescriptor_t outputDesc,
+                           void* output,
+                           miopenOperatorArgs_t args,
+                           void* workspace,
+                           size_t workspaceSize)
+{
+    MIOPEN_LOG_FUNCTION(
+        handle, fusePlanDesc, inputDesc, input, outputDesc, output, args, workspace, workspaceSize);
+
+    if(workspace == nullptr && workspaceSize != 0)
+    {
+        return miopenStatusBadParm;
+    }
+
+    return miopen::try_([&] {
+        miopen::deref(fusePlanDesc)
+            .Execute(miopen::deref(handle),
+                     miopen::deref(inputDesc),
+                     DataCast(input),
+                     miopen::deref(outputDesc),
+                     DataCast(output),
+                     miopen::deref(args),
+                     DataCast(workspace),
+                     workspaceSize);
+    });
+}
+
 // Return an error code that is "NotImplemented", if it exists then return success
 extern "C" miopenStatus_t miopenExecuteFusionPlan(const miopenHandle_t handle,
                                                   const miopenFusionPlanDescriptor_t fusePlanDesc,
@@ -431,15 +467,16 @@ extern "C" miopenStatus_t miopenExecuteFusionPlan(const miopenHandle_t handle,
                                                   miopenOperatorArgs_t args)
 {
     MIOPEN_LOG_FUNCTION(handle, fusePlanDesc, inputDesc, input, outputDesc, output, args);
-    return miopen::try_([&] {
-        miopen::deref(fusePlanDesc)
-            .Execute(miopen::deref(handle),
-                     miopen::deref(inputDesc),
-                     DataCast(input),
-                     miopen::deref(outputDesc),
-                     DataCast(output),
-                     miopen::deref(args));
-    });
+
+    return miopenExecuteFusionPlan_v2(handle,
+                                      fusePlanDesc,
+                                      inputDesc,
+                                      input,
+                                      outputDesc,
+                                      output,
+                                      args,
+                                      /*workspace=*/nullptr,
+                                      /*workspaceSize=*/0);
 }
 
 extern "C" miopenStatus_t
