@@ -39,6 +39,8 @@
 #include <memory>
 #include <typeinfo>
 
+#define FIN_ANY_SOLVER_FIND_SOLUTION_COMPAT
+
 namespace miopen {
 namespace solver {
 
@@ -60,10 +62,17 @@ struct AnySolver
     };
     bool TestPerfCfgParams(const ExecutionContext& ctx,
                            const miopen::conv::ProblemDescription& problem,
-                           const std::string& params) const
+                           const std::string& perf_cfg) const
     {
         assert(ptr_value != nullptr);
-        return ptr_value->TestPerfCfgParams(ctx, problem, params);
+        return ptr_value->TestPerfCfgParams(ctx, problem, perf_cfg);
+    };
+    ConvSolution GetSolution(const ExecutionContext& ctx,
+                             const miopen::conv::ProblemDescription& problem,
+                             const std::string& perf_cfg) const
+    {
+        assert(ptr_value != nullptr);
+        return ptr_value->GetSolution(ctx, problem, perf_cfg);
     };
     std::vector<ConvSolution> GetAllSolutions(const ExecutionContext& ctx,
                                               const miopen::conv::ProblemDescription& problem) const
@@ -87,6 +96,8 @@ struct AnySolver
         return ptr_value->Type();
     };
     bool IsEmpty() const { return ptr_value == nullptr; };
+
+#if defined(FIN_ANY_SOLVER_FIND_SOLUTION_COMPAT)
     ConvSolution FindSolution(const ExecutionContext& ctx,
                               const miopen::conv::ProblemDescription& problem,
                               PerformanceDb& db,
@@ -95,7 +106,38 @@ struct AnySolver
     {
         assert(ptr_value != nullptr);
         return ptr_value->FindSolution(ctx, problem, db, invoke_ctx, perf_cfg);
-    };
+    }
+#endif
+
+    ConvSolution FindSolution(const ExecutionContext& ctx,
+                              const miopen::conv::ProblemDescription& problem,
+                              std::function<PerformanceDb&()>& db_getter,
+                              const miopen::AnyInvokeParams& invoke_ctx,
+                              const std::string& perf_cfg = "") const
+    {
+        assert(ptr_value != nullptr);
+        return ptr_value->FindSolution(ctx, problem, db_getter, invoke_ctx, perf_cfg);
+    }
+
+    ConvSolution FindSolution(const ExecutionContext& ctx,
+                              const miopen::conv::ProblemDescription& problem,
+                              DbGetter& db_getter,
+                              const miopen::AnyInvokeParams& invoke_ctx,
+                              const std::string& perf_cfg = "") const
+    {
+        assert(ptr_value != nullptr);
+        return ptr_value->FindSolution(ctx, problem, db_getter, invoke_ctx, perf_cfg);
+    }
+
+    std::string GenericSearch(const ExecutionContext& ctx,
+                              const miopen::conv::ProblemDescription& problem,
+                              const miopen::AnyInvokeParams& invoke_ctx,
+                              std::vector<miopen::solver::SolutionPerf>* perf_sols = nullptr) const
+    {
+        assert(ptr_value != nullptr);
+        return ptr_value->GenericSearch(ctx, problem, invoke_ctx, perf_sols);
+    }
+
     InvokerFactory GetInvokeFactory(const ExecutionContext& ctx,
                                     const miopen::conv::ProblemDescription& problem,
                                     const std::string& perf_cfg = "") const
@@ -140,20 +182,38 @@ struct AnySolver
         virtual bool IsTunable() const                                                   = 0;
         virtual bool TestPerfCfgParams(const ExecutionContext& ctx,
                                        const miopen::conv::ProblemDescription& problem,
-                                       const std::string& params) const                  = 0;
+                                       const std::string& perf_cfg) const                = 0;
+        virtual ConvSolution GetSolution(const ExecutionContext& ctx,
+                                         const miopen::conv::ProblemDescription& problem,
+                                         const std::string& perf_cfg) const              = 0;
         virtual std::vector<ConvSolution>
         GetAllSolutions(const ExecutionContext& ctx,
-                        const miopen::conv::ProblemDescription& problem) const                 = 0;
-        virtual bool IsDynamic() const                                                         = 0;
+                        const miopen::conv::ProblemDescription& problem) const      = 0;
+        virtual bool IsDynamic() const                                              = 0;
         virtual float GetWti(const ExecutionContext& ctx,
-                             const miopen::conv::ProblemDescription& problem) const            = 0;
-        virtual const std::type_info& Type() const                                             = 0;
-        virtual std::string GetSolverDbId() const                                              = 0;
+                             const miopen::conv::ProblemDescription& problem) const = 0;
+        virtual const std::type_info& Type() const                                  = 0;
+        virtual std::string GetSolverDbId() const                                   = 0;
         virtual ConvSolution FindSolution(const ExecutionContext& ctx,
                                           const miopen::conv::ProblemDescription& problem,
                                           PerformanceDb& db,
                                           const miopen::AnyInvokeParams& invoke_ctx,
-                                          const std::string& perf_cfg) const                   = 0;
+                                          const std::string& perf_cfg) const        = 0;
+        virtual ConvSolution FindSolution(const ExecutionContext& ctx,
+                                          const miopen::conv::ProblemDescription& problem,
+                                          std::function<PerformanceDb&()>& db_getter,
+                                          const miopen::AnyInvokeParams& invoke_ctx,
+                                          const std::string& perf_cfg) const        = 0;
+        virtual ConvSolution FindSolution(const ExecutionContext& ctx,
+                                          const miopen::conv::ProblemDescription& problem,
+                                          DbGetter& db_getter,
+                                          const miopen::AnyInvokeParams& invoke_ctx,
+                                          const std::string& perf_cfg) const        = 0;
+        virtual std::string
+        GenericSearch(const ExecutionContext& ctx,
+                      const miopen::conv::ProblemDescription& problem,
+                      const miopen::AnyInvokeParams& invoke_ctx,
+                      std::vector<miopen::solver::SolutionPerf>* perf_sols) const              = 0;
         virtual InvokerFactory GetInvokeFactory(const ExecutionContext& ctx,
                                                 const miopen::conv::ProblemDescription& problem,
                                                 const std::string& perf_cfg) const             = 0;
@@ -202,7 +262,7 @@ struct AnySolver
 
         bool TestPerfCfgParams(const ExecutionContext& ctx,
                                const miopen::conv::ProblemDescription& problem,
-                               const std::string& params,
+                               const std::string& perf_cfg,
                                std::true_type) const
         {
             using PerformanceConfig = decltype(value.GetDefaultPerformanceConfig(
@@ -210,11 +270,11 @@ struct AnySolver
                 std::declval<const miopen::conv::ProblemDescription&>()));
             PerformanceConfig config{};
 
-            bool success = config.Deserialize(params);
+            bool success = config.Deserialize(perf_cfg);
             if(!success)
             {
                 MIOPEN_LOG_WE("Perf params are obsolete or corrupt: "
-                              << params << ". Performance may degrade.");
+                              << perf_cfg << ". Performance may degrade.");
                 return false;
             }
 
@@ -232,13 +292,22 @@ struct AnySolver
 
         bool TestPerfCfgParams(const ExecutionContext& ctx,
                                const miopen::conv::ProblemDescription& problem,
-                               const std::string& params) const override
+                               const std::string& perf_cfg) const override
         {
             return TestPerfCfgParams(
-                ctx, problem, params, std::integral_constant<bool, TunableSolver::Is>());
+                ctx, problem, perf_cfg, std::integral_constant<bool, TunableSolver::Is>());
         }
 
         // tunable legacy solver
+        ConvSolution GetSolution(const ExecutionContext&,
+                                 const miopen::conv::ProblemDescription&,
+                                 const std::string&,
+                                 std::true_type,
+                                 std::true_type) const
+        {
+            MIOPEN_THROW("No solutions returned for Legacy Solvers.");
+        }
+
         std::vector<ConvSolution> GetAllSolutions(const ExecutionContext&,
                                                   const miopen::conv::ProblemDescription&,
                                                   std::true_type,
@@ -248,6 +317,21 @@ struct AnySolver
         }
 
         // tunable solver, not legacy
+        ConvSolution GetSolution(const ExecutionContext& ctx,
+                                 const miopen::conv::ProblemDescription& problem,
+                                 const std::string& perf_cfg,
+                                 std::true_type,
+                                 std::false_type) const
+        {
+            using PerformanceConfig = decltype(value.GetDefaultPerformanceConfig(ctx, problem));
+            PerformanceConfig config{};
+            bool success = config.Deserialize(perf_cfg);
+            if(!success)
+                MIOPEN_THROW("Failed to deserialize parameters.");
+
+            return value.GetSolution(ctx, problem, config);
+        }
+
         std::vector<ConvSolution> GetAllSolutions(const ExecutionContext& ctx,
                                                   const miopen::conv::ProblemDescription& problem,
                                                   std::true_type,
@@ -257,6 +341,23 @@ struct AnySolver
         }
 
         // non tunable solver
+        ConvSolution GetSolution(const ExecutionContext& ctx,
+                                 const miopen::conv::ProblemDescription& problem,
+                                 const std::string&,
+                                 std::false_type,
+                                 std::true_type) const
+        {
+            return value.GetSolution(ctx, problem);
+        }
+        ConvSolution GetSolution(const ExecutionContext& ctx,
+                                 const miopen::conv::ProblemDescription& problem,
+                                 const std::string&,
+                                 std::false_type,
+                                 std::false_type) const
+        {
+            return value.GetSolution(ctx, problem);
+        }
+
         std::vector<ConvSolution> GetAllSolutions(const ExecutionContext& ctx,
                                                   const miopen::conv::ProblemDescription& problem,
                                                   std::false_type,
@@ -276,6 +377,17 @@ struct AnySolver
             return solutions;
         }
 
+        ConvSolution GetSolution(const ExecutionContext& ctx,
+                                 const miopen::conv::ProblemDescription& problem,
+                                 const std::string& perf_cfg) const override
+        {
+            return GetSolution(ctx,
+                               problem,
+                               perf_cfg,
+                               std::integral_constant<bool, TunableSolver::Is>(),
+                               std::integral_constant<bool, LegacySolver::Is>());
+        }
+
         std::vector<ConvSolution>
         GetAllSolutions(const ExecutionContext& ctx,
                         const miopen::conv::ProblemDescription& problem) const override
@@ -308,7 +420,85 @@ struct AnySolver
                                   const std::string& perf_cfg) const override
         {
             return miopen::solver::FindSolution(value, ctx, problem, db, invoke_ctx, perf_cfg);
-        };
+        }
+
+        ConvSolution FindSolution(const ExecutionContext& ctx,
+                                  const miopen::conv::ProblemDescription& problem,
+                                  std::function<PerformanceDb&()>& db_getter,
+                                  const miopen::AnyInvokeParams& invoke_ctx,
+                                  const std::string& perf_cfg) const override
+        {
+            return miopen::solver::FindSolution(
+                value, ctx, problem, db_getter, invoke_ctx, perf_cfg);
+        }
+
+        ConvSolution FindSolution(const ExecutionContext& ctx,
+                                  const miopen::conv::ProblemDescription& problem,
+                                  DbGetter& db_getter,
+                                  const miopen::AnyInvokeParams& invoke_ctx,
+                                  const std::string& perf_cfg) const override
+        {
+            return miopen::solver::FindSolution(
+                value, ctx, problem, db_getter, invoke_ctx, perf_cfg);
+        }
+
+        // tunable legacy solver
+        std::string GenericSearch(const ExecutionContext&,
+                                  const miopen::conv::ProblemDescription&,
+                                  const miopen::AnyInvokeParams&,
+                                  std::vector<miopen::solver::SolutionPerf>*,
+                                  std::true_type,
+                                  std::true_type) const
+        {
+            MIOPEN_THROW("No GenericSearch for Legacy Solvers.");
+        }
+
+        // tunable solver
+        std::string GenericSearch(const ExecutionContext& ctx,
+                                  const miopen::conv::ProblemDescription& problem,
+                                  const miopen::AnyInvokeParams& invoke_ctx,
+                                  std::vector<miopen::solver::SolutionPerf>* perf_sols,
+                                  std::true_type,
+                                  std::false_type) const
+        {
+            auto config = miopen::solver::GenericSearch(value, ctx, problem, invoke_ctx, perf_sols);
+            return config.ToString();
+        }
+
+        // non-tunable solver has no search
+        std::string GenericSearch(const ExecutionContext&,
+                                  const miopen::conv::ProblemDescription&,
+                                  const miopen::AnyInvokeParams&,
+                                  std::vector<miopen::solver::SolutionPerf>*,
+                                  std::false_type,
+                                  std::true_type) const
+        {
+            MIOPEN_THROW("No GenericSearch for non-tunable Solvers.");
+        }
+
+        std::string GenericSearch(const ExecutionContext&,
+                                  const miopen::conv::ProblemDescription&,
+                                  const miopen::AnyInvokeParams&,
+                                  std::vector<miopen::solver::SolutionPerf>*,
+                                  std::false_type,
+                                  std::false_type) const
+        {
+            MIOPEN_THROW("No GenericSearch for non-tunable Solvers.");
+        }
+
+        std::string
+        GenericSearch(const ExecutionContext& ctx,
+                      const miopen::conv::ProblemDescription& problem,
+                      const miopen::AnyInvokeParams& invoke_ctx,
+                      std::vector<miopen::solver::SolutionPerf>* perf_sols) const override
+        {
+            return GenericSearch(ctx,
+                                 problem,
+                                 invoke_ctx,
+                                 perf_sols,
+                                 std::integral_constant<bool, TunableSolver::Is>(),
+                                 std::integral_constant<bool, LegacySolver::Is>());
+        }
 
         InvokerFactory GetInvokeFactory(const ExecutionContext& ctx,
                                         const miopen::conv::ProblemDescription& problem,
