@@ -117,8 +117,6 @@ static auto GetImplicitGemmSolvers()
         miopen::solver::conv::ConvHipImplicitGemmGroupBwdXdlops,
         miopen::solver::conv::ConvHipImplicitGemm3DGroupFwdXdlops,
         miopen::solver::conv::ConvHipImplicitGemm3DGroupBwdXdlops,
-        miopen::solver::conv::ConvHipImplicitGemmF16F8F16FwdXdlops,
-        miopen::solver::conv::ConvHipImplicitGemmF16F8F16BwdXdlops,
 #endif // MIOPEN_BACKEND_HIP && MIOPEN_USE_COMPOSABLEKERNEL
         miopen::solver::conv::ConvAsmImplicitGemmGTCDynamicFwdDlopsNCHWC>{};
 }
@@ -131,6 +129,7 @@ static auto GetWindogradSolvers()
         miopen::solver::conv::ConvBinWinoRxS<2, 3>,
         miopen::solver::conv::ConvBinWinogradRxSf2x3g1,
         miopen::solver::conv::ConvBinWinogradRxS,
+        miopen::solver::conv::ConvMPBidirectWinograd<2, 3>,
         miopen::solver::conv::ConvMPBidirectWinograd<3, 3>,
         miopen::solver::conv::ConvMPBidirectWinograd<4, 3>,
         miopen::solver::conv::ConvMPBidirectWinograd<5, 3>,
@@ -140,7 +139,8 @@ static auto GetWindogradSolvers()
         miopen::solver::conv::ConvMPBidirectWinograd_xdlops<4, 3>,
         miopen::solver::conv::ConvMPBidirectWinograd_xdlops<5, 3>,
         miopen::solver::conv::ConvMPBidirectWinograd_xdlops<6, 3>,
-        miopen::solver::conv::ConvWinoFuryRxS<2, 3>>{};
+        miopen::solver::conv::ConvWinoFuryRxS<2, 3>,
+        miopen::solver::conv::ConvWinoRageRxS<2, 3>>{};
 }
 
 static auto GetImplicitGemmWrWSolvers()
@@ -157,7 +157,6 @@ static auto GetImplicitGemmWrWSolvers()
 #if MIOPEN_BACKEND_HIP && MIOPEN_USE_COMPOSABLEKERNEL
         miopen::solver::conv::ConvHipImplicitGemmGroupWrwXdlops,
         miopen::solver::conv::ConvHipImplicitGemm3DGroupWrwXdlops,
-        miopen::solver::conv::ConvHipImplicitGemmF16F8F16WrwXdlops,
 #endif // MIOPEN_BACKEND_HIP && MIOPEN_USE_COMPOSABLEKERNEL
         miopen::solver::conv::ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC>{};
 }
@@ -182,7 +181,8 @@ static auto GetWindogradWrWSolvers()
         miopen::solver::conv::ConvWinograd3x3MultipassWrW<1, 1, 7, 3>,
         miopen::solver::conv::ConvWinograd3x3MultipassWrW<5, 3>,
         miopen::solver::conv::ConvWinograd3x3MultipassWrW<5, 4>,
-        miopen::solver::conv::ConvWinoFuryRxS<2, 3>>{};
+        miopen::solver::conv::ConvWinoFuryRxS<2, 3>,
+        miopen::solver::conv::ConvWinoRageRxS<2, 3>>{};
 }
 
 static auto GetBwdWrW2DSolvers()
@@ -204,12 +204,28 @@ static auto GetBwdWrW2DSolvers()
 
 static auto GetFFTSolvers() { return miopen::solver::SolverContainer<miopen::solver::conv::fft>{}; }
 
+miopen::DbGetter::DbGetter(std::function<PerformanceDb()>&& init_) : init(init_) {}
+
+auto miopen::DbGetter::operator()() -> PerformanceDb&
+{
+    if(!db)
+        db.emplace(init());
+
+    return *db;
+}
+
+auto miopen::MakeConvDbGetter(const ExecutionContext& ctx) -> DbGetter
+{
+    return DbGetter{[&]() { return GetDb(ctx); }};
+}
+
 std::vector<miopen::solver::ConvSolution>
 FindAllGemmSolutions(const miopen::ExecutionContext& ctx,
                      const miopen::conv::ProblemDescription& problem,
                      const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetGemmSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetGemmSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<std::pair<std::string, size_t>>
@@ -224,7 +240,8 @@ FindAllDirectSolutions(const miopen::ExecutionContext& ctx,
                        const miopen::conv::ProblemDescription& problem,
                        const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetDirectSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetDirectSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<std::pair<std::string, size_t>>
@@ -260,7 +277,8 @@ FindAllImplicitGemmSolutions(const miopen::ExecutionContext& ctx,
                              const miopen::conv::ProblemDescription& problem,
                              const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetImplicitGemmSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetImplicitGemmSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<miopen::solver::ConvSolution>
@@ -268,7 +286,8 @@ FindAllWinogradSolutions(const miopen::ExecutionContext& ctx,
                          const miopen::conv::ProblemDescription& problem,
                          const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetWindogradSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetWindogradSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<miopen::solver::ConvSolution>
@@ -276,7 +295,8 @@ FindWinogradWrWAllSolutions(const miopen::ExecutionContext& ctx,
                             const miopen::conv::ProblemDescription& problem,
                             const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetWindogradWrWSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetWindogradWrWSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<std::pair<std::string, size_t>>
@@ -298,7 +318,8 @@ FindImplicitGemmWrWAllSolutions(const miopen::ExecutionContext& ctx,
                                 const miopen::conv::ProblemDescription& problem,
                                 const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetImplicitGemmWrWSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetImplicitGemmWrWSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<miopen::solver::ConvSolution>
@@ -306,7 +327,8 @@ FindAllBwdWrW2DSolutions(const miopen::ExecutionContext& ctx,
                          const miopen::conv::ProblemDescription& problem,
                          const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetBwdWrW2DSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetBwdWrW2DSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<miopen::solver::ConvSolution>
@@ -314,7 +336,8 @@ FindAllFFTSolutions(const miopen::ExecutionContext& ctx,
                     const miopen::conv::ProblemDescription& problem,
                     const miopen::AnyInvokeParams& invoke_ctx)
 {
-    return GetFFTSolvers().SearchForAllSolutions(ctx, problem, GetDb(ctx), invoke_ctx);
+    return GetFFTSolvers().SearchForAllSolutions(
+        ctx, problem, miopen::MakeConvDbGetter(ctx), invoke_ctx);
 }
 
 std::vector<std::pair<std::string, size_t>>
