@@ -57,7 +57,7 @@ miopen::PerformanceDb GetDb(const miopen::ExecutionContext& ctx,
 
 //============ BEGIN FORWARD TRAINING ===============
 
-void BatchNormForwardTraining(Handle& handle,
+void BatchNormForwardTraining(const Handle& handle,
                               miopenBatchNormMode_t bn_mode,
                               const void* alpha,
                               const void* beta,
@@ -76,7 +76,8 @@ void BatchNormForwardTraining(Handle& handle,
                               Data_t resultRunningVariance,
                               double epsilon,
                               Data_t resultSaveMean,
-                              Data_t resultSaveInvVariance)
+                              Data_t resultSaveInvVariance,
+                              const ActivationDescriptor& activDesc)
 {
     if(x == nullptr || y == nullptr || bnScale == nullptr || bnBias == nullptr)
     {
@@ -129,14 +130,16 @@ void BatchNormForwardTraining(Handle& handle,
                                                        expAvgFactor,
                                                        epsilon,
                                                        resultsave,
-                                                       resultrunning};
+                                                       resultrunning,
+                                                       size_t(0.6f * handle.GetMaxComputeUnits()),
+                                                       activDesc};
 
     const auto algo = bn_mode == miopenBNSpatial
                           ? AlgorithmName{"miopenBatchNormForwardTrainingSpatial"}
                           : AlgorithmName{"miopenBatchNormForwardTrainingPerActivation"};
 
     const auto invoke_params = [&]() {
-        auto tmp                  = batchnorm::InvokeParams{};
+        auto tmp                  = miopen::batchnorm::FwdTrainInvokeParams{};
         tmp.type                  = InvokeType::Run;
         tmp.x                     = x;
         tmp.y                     = y;
@@ -151,9 +154,7 @@ void BatchNormForwardTraining(Handle& handle,
         return tmp;
     }();
 
-    const auto solvers = solver::SolverContainer<solver::batchnorm::BnCKFwdTraining,
-                                                 solver::batchnorm::BnFwdTrainingSpatialSingle,
-                                                 solver::batchnorm::BnFwdTrainingSpatialMultiple,
+    const auto solvers = solver::SolverContainer<solver::batchnorm::BnFwdTrainingSpatial,
                                                  solver::batchnorm::BnFwdTrainingPerActivation>{};
 
     solvers.ExecutePrimitive(handle, problem, algo, invoke_params);
@@ -175,7 +176,7 @@ void BatchNormForwardTraining(Handle& handle,
 //================== END FWD TRAIN ===================
 
 //============ BEGIN FORWARD INFERENCE ===============
-void BatchNormForwardInference(Handle& handle,
+void BatchNormForwardInference(const Handle& handle,
                                miopenBatchNormMode_t bn_mode,
                                const void* alpha,
                                const void* beta,
@@ -191,7 +192,8 @@ void BatchNormForwardInference(Handle& handle,
                                ConstData_t bnBias,
                                ConstData_t estimatedMean,
                                ConstData_t estimatedVariance,
-                               double epsilon)
+                               double epsilon,
+                               const ActivationDescriptor& activDesc)
 {
 
     if(miopen::CheckNumericsEnabled())
@@ -232,8 +234,15 @@ void BatchNormForwardInference(Handle& handle,
             MIOPEN_THROW(miopenStatusBadParm);
         }
 
-        const auto problem = batchnorm::ProblemDescription{
-            bn_mode, xDesc, yDesc, scaleDesc, biasDesc, estMeanDesc, estVarianceDesc, epsilon};
+        const auto problem = batchnorm::ProblemDescription{bn_mode,
+                                                           xDesc,
+                                                           yDesc,
+                                                           scaleDesc,
+                                                           biasDesc,
+                                                           estMeanDesc,
+                                                           estVarianceDesc,
+                                                           epsilon,
+                                                           activDesc};
 
         const auto invoke_params = [&]() {
             auto tmp              = batchnorm::InfInvokeParams{};
@@ -250,8 +259,7 @@ void BatchNormForwardInference(Handle& handle,
         }();
 
         const auto algo    = AlgorithmName{"miopenBatchNormalizationForwardInference"};
-        const auto solvers = solver::SolverContainer<solver::batchnorm::BnFwdInference,
-                                                     solver::batchnorm::BnCKFwdInference>{};
+        const auto solvers = solver::SolverContainer<solver::batchnorm::BnFwdInference>{};
 
         solvers.ExecutePrimitive(handle, problem, algo, invoke_params);
     }
@@ -277,7 +285,8 @@ void BatchNormForwardInference(Handle& handle,
                                  nullptr,
                                  epsilon,
                                  nullptr,
-                                 nullptr);
+                                 nullptr,
+                                 activDesc);
     }
     if(miopen::CheckNumericsEnabled())
     {
@@ -289,7 +298,7 @@ void BatchNormForwardInference(Handle& handle,
 
 //=============== BEGIN BACKWARDS PROPAGATION ================
 
-void BatchNormBackward(Handle& handle,
+void BatchNormBackward(const Handle& handle,
                        miopenBatchNormMode_t bn_mode,
                        const void* alphaDataDiff,
                        const void* betaDataDiff,
@@ -306,11 +315,13 @@ void BatchNormBackward(Handle& handle,
                        const TensorDescriptor& savedMeanDesc,
                        const TensorDescriptor& savedVarianceDesc,
                        ConstData_t bnScale,
+                       ConstData_t bnBias,
                        Data_t resultBnScaleDiff,
                        Data_t resultBnBiasDiff,
                        double epsilon,
                        ConstData_t savedMean,
-                       ConstData_t savedInvVariance)
+                       ConstData_t savedInvVariance,
+                       const ActivationDescriptor& activDesc)
 {
 
 #if(MIO_BN_TIME_EVERYTHING == 1)
@@ -372,7 +383,9 @@ void BatchNormBackward(Handle& handle,
                                                        savedMeanDesc,
                                                        savedVarianceDesc,
                                                        epsilon,
-                                                       useSaved};
+                                                       useSaved,
+                                                       size_t(0.6f * handle.GetMaxComputeUnits()),
+                                                       activDesc};
 
     const auto algo = bn_mode == miopenBNSpatial
                           ? AlgorithmName{"miopenBatchNormBackwardPropSpatial"}
@@ -385,6 +398,7 @@ void BatchNormBackward(Handle& handle,
         tmp.dy                = dy;
         tmp.dx                = dx;
         tmp.bnScale           = bnScale;
+        tmp.bnBias            = bnBias;
         tmp.resultBnScaleDiff = resultBnScaleDiff;
         tmp.resultBnBiasDiff  = resultBnBiasDiff;
         tmp.epsilon           = epsilon;
@@ -393,9 +407,7 @@ void BatchNormBackward(Handle& handle,
         return tmp;
     }();
 
-    const auto solvers = solver::SolverContainer<solver::batchnorm::BnCKBwdBackward,
-                                                 solver::batchnorm::BnBwdTrainingSpatialSingle,
-                                                 solver::batchnorm::BnBwdTrainingSpatialMultiple,
+    const auto solvers = solver::SolverContainer<solver::batchnorm::BnBwdTrainingSpatial,
                                                  solver::batchnorm::BnBwdTrainingPerActivation>{};
 
     solvers.ExecutePrimitive(handle, problem, algo, invoke_params);
