@@ -26,6 +26,7 @@
 
 #include <miopen/mlo_internal.hpp>
 #include <miopen/logger.hpp>
+#include <numbers>
 
 // KNOWN ISSUES:
 // backward propogagation has a bug in cross map normalization when numper of maps less than
@@ -33,7 +34,7 @@
 
 void mlo_construct_norm::mloConstruct()
 {
-    if(_problem.direction.IsForward())
+    if(_problem.IsDirectionForward())
     {
         mloConstructFwd();
     }
@@ -104,9 +105,9 @@ int mlo_construct_norm::mloConstructFwd()
     assert(_out_pix_tile0 - 1 <= _norm_area && _out_pix_tile1 - 1 <= _norm_area);
 
     auto ocl_group_lg2sz0 =
-        static_cast<int>(ceil(log(static_cast<double>(_out_pix_tile0)) / log(2.)));
+        static_cast<int>(ceil(log(static_cast<double>(_out_pix_tile0)) / std::numbers::ln2));
     auto ocl_group_lg2sz1 =
-        static_cast<int>(ceil(log(static_cast<double>(_out_pix_tile1)) / log(2.)));
+        static_cast<int>(ceil(log(static_cast<double>(_out_pix_tile1)) / std::numbers::ln2));
 
     _kernel_file = "MIOpenLRNFwd.cl";
     _kernel_name = (_norm_region == MLO_LRN_ACROSS_CHANNELS) ? "MIOpenLRNAcrossChannels4"
@@ -289,8 +290,10 @@ int mlo_construct_norm::mloConstructBwd()
         _out_pix_tile0 = (_in_df_width <= 8) ? 1 : (_in_df_width <= 16) ? 2 : 4;
         _out_pix_tile1 = (_in_df_height <= 8) ? 1 : (_in_df_height <= 16) ? 2 : 4;
     }
-    auto ocl_group_lg2sz0 = static_cast<int>(ceil(log(static_cast<double>(_grp_tile0)) / log(2.)));
-    auto ocl_group_lg2sz1 = static_cast<int>(ceil(log(static_cast<double>(_grp_tile1)) / log(2.)));
+    auto ocl_group_lg2sz0 =
+        static_cast<int>(ceil(log(static_cast<double>(_grp_tile0)) / std::numbers::ln2));
+    auto ocl_group_lg2sz1 =
+        static_cast<int>(ceil(log(static_cast<double>(_grp_tile1)) / std::numbers::ln2));
 
     int pre_pad              = (_norm_area - 1) / 2;
     int pad                  = _norm_area - pre_pad - 1;
