@@ -23,15 +23,17 @@
  * SOFTWARE.
  *
  *******************************************************************************/
-#include <cmath>
-#include <miopen/kernel_cache.hpp>
-#include <miopen/util.hpp>
-#include <miopen/logger.hpp>
-#include <miopen/float_equal.hpp>
 #include <miopen/datatype.hpp>
+#include <miopen/float_equal.hpp>
+#include <miopen/kernel_cache.hpp>
+#include <miopen/logger.hpp>
+#include <miopen/util.hpp>
 
 #include <boost/range/adaptors.hpp>
 
+#include <cmath>
+#include <cstdint>
+
 #define WG_SIZE (static_cast<size_t>(256))
 #define MAX_ACTIVE_THREADS (64 * 4 * 64)
 #define MAX_LOCAL_MEM 65536
@@ -40,7 +42,7 @@ namespace miopen {
 
 float Im2d2ColGPU(const Handle& handle,
                   ConstData_t im,
-                  const int im_offset,
+                  const size_t im_offset,
                   const int c,
                   const int in_h,
                   const int in_w,
@@ -58,7 +60,7 @@ float Im2d2ColGPU(const Handle& handle,
                   miopenDataType_t type)
 {
     std::string program_name = "MIOpenIm2d2Col.cl";
-    std::string kernel_name  = "Im2d2Col";
+    std::string kernel_name  = "Im2d2Col_v2";
 
     // clang-format off
     std::string network_config =
@@ -78,17 +80,14 @@ float Im2d2ColGPU(const Handle& handle,
 
     auto&& kernels = handle.GetKernels("miopenIm2d2Col", network_config);
 
-    int data_size_bound = c * in_h * in_w;
-
-    int data_size_bound_pack = data_size_bound;
-    int im_offset_pack       = im_offset;
+    const int data_size_bound = c * in_h * in_w;
 
     if(!kernels.empty())
     {
         auto kernel = kernels.front();
-        kernel(data_size_bound_pack,
+        kernel(data_size_bound,
                im,
-               im_offset_pack,
+               im_offset,
                in_h,
                in_w,
                wei_h,
@@ -148,6 +147,8 @@ float Im2d2ColGPU(const Handle& handle,
         {
             params += " -DEXTREME_LARGE";
             params += " -DNUM_CH_TOTAL=" + std::to_string(c_pack);
+            network_config += " -DEXTREME_LARGE";
+            network_config += " -DNUM_CH_TOTAL=" + std::to_string(c_pack);
         }
         else
         {
@@ -188,6 +189,13 @@ float Im2d2ColGPU(const Handle& handle,
         params += " -DNUM_IM_BLKS_EQ_1=" + std::to_string(static_cast<int>(num_blks == 1));
         params += " -DUSE_IM_OFF_GUARD=1"; // always one
 
+        network_config += " -DLOCAL_MEM_SIZE=" +
+                          std::to_string(local_mem_sz); // needs some changes to the kernel launch
+        network_config +=
+            " -DSTRIDE_GT_1=" + std::to_string(static_cast<int>(stride_h * stride_w > 1));
+        network_config += " -DNUM_IM_BLKS_EQ_1=" + std::to_string(static_cast<int>(num_blks == 1));
+        network_config += " -DUSE_IM_OFF_GUARD=1"; // always one
+
         params += GetDataTypeKernelParams(type);
 
         const int group_size_x = 256;
@@ -250,13 +258,16 @@ float Im2d2ColGPU(const Handle& handle,
         }
 
         if(use_64bit_buffer_index)
+        {
             params += " -DUSE_LARGE_BUFFER_INDEX";
+            network_config += " -DUSE_LARGE_BUFFER_INDEX";
+        }
 
         handle.AddKernel(
-            "miopenIm2Col", network_config, program_name, kernel_name, vld, vgd, params)(
-            data_size_bound_pack,
+            "miopenIm2d2Col", network_config, program_name, kernel_name, vld, vgd, params)(
+            data_size_bound,
             im,
-            im_offset_pack,
+            im_offset,
             in_h,
             in_w,
             wei_h,
@@ -403,25 +414,25 @@ float Im3d2ColGPU(const Handle& handle,
 
 float Col2Im2dGPU(const Handle& handle,
                   ConstData_t col,
-                  const int out_h,
-                  const int out_w,
-                  const int wei_h,
-                  const int wei_w,
-                  const int pad_h,
-                  const int pad_w,
-                  const int stride_h,
-                  const int stride_w,
-                  const int dilation_h,
-                  const int dilation_w,
-                  const int in_c,
-                  const int in_h,
-                  const int in_w,
+                  const uint32_t out_h,
+                  const uint32_t out_w,
+                  const uint32_t wei_h,
+                  const uint32_t wei_w,
+                  const uint32_t pad_h,
+                  const uint32_t pad_w,
+                  const uint32_t stride_h,
+                  const uint32_t stride_w,
+                  const uint32_t dilation_h,
+                  const uint32_t dilation_w,
+                  const uint32_t in_c,
+                  const uint32_t in_h,
+                  const uint32_t in_w,
                   Data_t im,
-                  int im_offset,
+                  uint32_t im_offset,
                   miopenDataType_t type)
 {
     std::string program_name = "MIOpenCol2Im2d.cl";
-    std::string kernel_name  = "Col2Im2d";
+    std::string kernel_name  = "Col2Im2dU";
 
     // clang-format off
     std::string network_config =
@@ -468,6 +479,17 @@ float Col2Im2dGPU(const Handle& handle,
         const std::vector<size_t> vgd{global_threads, 1, 1};
         const std::vector<size_t> vld{std::min(WG_SIZE, global_threads), 1, 1};
 
+        auto Is64BitIndexRequired = [&]() -> int {
+            const auto im_ch_max     = global_threads / static_cast<size_t>(in_w * in_h);
+            const auto ch_offset_max = im_ch_max * out_w * out_h * wei_w * wei_h;
+            MIOPEN_LOG_T("global_threads, out_h, out_w, wei_h, wei_w = "
+                         << '{' << global_threads << ',' << out_h << ',' << out_w << ',' << wei_h
+                         << ',' << wei_w << '}' << " ch_offset_max = " << ch_offset_max);
+            return (ch_offset_max > 0xffffffffULL) ? 1 : 0;
+        };
+
+        params += " -DMIOPEN_USE_64BIT_INDEX=" + std::to_string(Is64BitIndexRequired());
+
         handle.AddKernel(
             "miopenCol2Im2d", network_config, program_name, kernel_name, vld, vgd, params)(
             col,
@@ -491,31 +513,31 @@ float Col2Im2dGPU(const Handle& handle,
 
 float Col2Im3dGPU(const Handle& handle,
                   ConstData_t col,
-                  const int out_d,
-                  const int out_h,
-                  const int out_w,
-                  const int wei_d,
-                  const int wei_h,
-                  const int wei_w,
-                  const int pad_d,
-                  const int pad_h,
-                  const int pad_w,
-                  const int stride_d,
-                  const int stride_h,
-                  const int stride_w,
-                  const int dilation_d,
-                  const int dilation_h,
-                  const int dilation_w,
-                  const int in_c,
-                  const int in_d,
-                  const int in_h,
-                  const int in_w,
+                  const uint32_t out_d,
+                  const uint32_t out_h,
+                  const uint32_t out_w,
+                  const uint32_t wei_d,
+                  const uint32_t wei_h,
+                  const uint32_t wei_w,
+                  const uint32_t pad_d,
+                  const uint32_t pad_h,
+                  const uint32_t pad_w,
+                  const uint32_t stride_d,
+                  const uint32_t stride_h,
+                  const uint32_t stride_w,
+                  const uint32_t dilation_d,
+                  const uint32_t dilation_h,
+                  const uint32_t dilation_w,
+                  const uint32_t in_c,
+                  const uint32_t in_d,
+                  const uint32_t in_h,
+                  const uint32_t in_w,
                   Data_t im,
                   std::size_t im_offset,
                   miopenDataType_t type)
 {
     std::string program_name = "MIOpenCol2Im3d.cl";
-    std::string kernel_name  = "Col2Im3d";
+    std::string kernel_name  = "Col2Im3dU";
 
     // clang-format off
     std::string network_config =
@@ -700,12 +722,12 @@ float Col2ImGPU(
                            out_spatial[1],
                            wei_spatial[0],
                            wei_spatial[1],
-                           pad_spatial[0],
-                           pad_spatial[1],
-                           stride_spatial[0],
-                           stride_spatial[1],
-                           dilation_spatial[0],
-                           dilation_spatial[1],
+                           static_cast<uint32_t>(pad_spatial[0]),
+                           static_cast<uint32_t>(pad_spatial[1]),
+                           static_cast<uint32_t>(stride_spatial[0]),
+                           static_cast<uint32_t>(stride_spatial[1]),
+                           static_cast<uint32_t>(dilation_spatial[0]),
+                           static_cast<uint32_t>(dilation_spatial[1]),
                            in_c,
                            in_spatial[0],
                            in_spatial[1],
@@ -722,15 +744,15 @@ float Col2ImGPU(
                            wei_spatial[0],
                            wei_spatial[1],
                            wei_spatial[2],
-                           pad_spatial[0],
-                           pad_spatial[1],
-                           pad_spatial[2],
-                           stride_spatial[0],
-                           stride_spatial[1],
-                           stride_spatial[2],
-                           dilation_spatial[0],
-                           dilation_spatial[1],
-                           dilation_spatial[2],
+                           static_cast<uint32_t>(pad_spatial[0]),
+                           static_cast<uint32_t>(pad_spatial[1]),
+                           static_cast<uint32_t>(pad_spatial[2]),
+                           static_cast<uint32_t>(stride_spatial[0]),
+                           static_cast<uint32_t>(stride_spatial[1]),
+                           static_cast<uint32_t>(stride_spatial[2]),
+                           static_cast<uint32_t>(dilation_spatial[0]),
+                           static_cast<uint32_t>(dilation_spatial[1]),
+                           static_cast<uint32_t>(dilation_spatial[2]),
                            in_c,
                            in_spatial[0],
                            in_spatial[1],
@@ -802,9 +824,9 @@ float transpose_NCHW2CNHW(const Handle& handle,
         auto&& kernels = handle.GetKernels(kernel_name, network_config);
         if(!kernels.empty())
         {
-            auto kernel  = kernels.front();
-            kernel.ldims = {{vld[0], vld[1], vld[2]}};
-            kernel.gdims = {{vgd[0], vgd[1], vgd[2]}};
+            auto kernel = kernels.front();
+            kernel.SetLocalDims(vld[0], vld[1], vld[2]);
+            kernel.SetGlobalDims(vgd[0], vgd[1], vgd[2]);
             kernel(in, out, in_offset, out_offset, RD_BLCK, HW_RD, n, c, h_in, w_in);
         }
         else
@@ -843,9 +865,9 @@ float transpose_NCHW2CNHW(const Handle& handle,
         auto&& kernels = handle.GetKernels(kernel_name, network_config);
         if(!kernels.empty())
         {
-            auto kernel  = kernels.front();
-            kernel.ldims = {{vld[0], vld[1], vld[2]}};
-            kernel.gdims = {{vgd[0], vgd[1], vgd[2]}};
+            auto kernel = kernels.front();
+            kernel.SetLocalDims(vld[0], vld[1], vld[2]);
+            kernel.SetGlobalDims(vgd[0], vgd[1], vgd[2]);
             kernel(in,
                    out,
                    in_offset,
@@ -935,9 +957,9 @@ float transpose_CNHW2NCHW(const Handle& handle,
         auto&& kernels = handle.GetKernels(kernel_name, network_config);
         if(!kernels.empty())
         {
-            auto kernel  = kernels.front();
-            kernel.ldims = {{vld[0], vld[1], vld[2]}};
-            kernel.gdims = {{vgd[0], vgd[1], vgd[2]}};
+            auto kernel = kernels.front();
+            kernel.SetLocalDims(vld[0], vld[1], vld[2]);
+            kernel.SetGlobalDims(vgd[0], vgd[1], vgd[2]);
             kernel(in, out, in_offset, out_offset, RD_BLCK, HW_RD, n, c, h_out, w_out);
         }
         else
@@ -980,9 +1002,9 @@ float transpose_CNHW2NCHW(const Handle& handle,
         auto&& kernels = handle.GetKernels(kernel_name, network_config);
         if(!kernels.empty())
         {
-            auto kernel  = kernels.front();
-            kernel.ldims = {{vld[0], vld[1], vld[1]}};
-            kernel.gdims = {{vgd[0], vgd[1], vgd[2]}};
+            auto kernel = kernels.front();
+            kernel.SetLocalDims(vld[0], vld[1], vld[2]);
+            kernel.SetGlobalDims(vgd[0], vgd[1], vgd[2]);
             kernel(in,
                    out,
                    in_offset,
@@ -1177,14 +1199,13 @@ float transpose_packed_MN2NM(const Handle& handle,
 
     if(!kernels.empty())
     {
-        auto kernel  = kernels.front();
-        kernel.ldims = {{vld[0], vld[1], vld[1]}};
-        kernel.gdims = {{vgd[0], vgd[1], vgd[2]}};
+        auto kernel = kernels.front();
+        kernel.SetLocalDims(vld[0], vld[1], vld[2]);
+        kernel.SetGlobalDims(vgd[0], vgd[1], vgd[2]);
         kernel(in, out, n, m, in_offset, out_offset);
     }
     else
     {
-
         handle.AddKernel(kernel_name, network_config, program_name, kernel_name, vld, vgd, params)(
             in, out, n, m, in_offset, out_offset);
     }
