@@ -830,10 +830,6 @@ bool ConvHipImplicitGemmBwdDataV4R1Xdlops::IsApplicable(const ExecutionContext&
         if(!env::enabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_BWD_V4R1_XDLOPS))
             return false;
     }
-#endif
-#if WORKAROUND_SWDEV_498660
-    if(!env::enabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_BWD_V4R1_XDLOPS))
-        return false;
 #endif
     if(env::disabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_BWD_V4R1_XDLOPS))
         return false;
@@ -843,13 +839,9 @@ bool ConvHipImplicitGemmBwdDataV4R1Xdlops::IsApplicable(const ExecutionContext&
         return false;
     if(!static_ck::IsComposableKernelSupportedHardware(ctx))
         return false;
-    if(problem.IsBfp16())
-    {
-        // Missing intrinsic: llvm.amdgcn.mfma.f32.16x16x8bf16
-        const auto dev_name = ctx.GetStream().GetDeviceName();
-        if(dev_name == "gfx942")
-            return false;
-    }
+    // Missing intrinsic: llvm.amdgcn.mfma.f32.16x16x8bf16
+    if(problem.IsBfp16() && static_ck::GfxHasMissingBf16Intrinsics(ctx.GetStream().GetDeviceName()))
+        return false;
     if(!problem.IsDirectionBackwardData())
         return false;
     if(!ctx.use_hip_kernels)
@@ -1067,8 +1059,11 @@ ConvSolution ConvHipImplicitGemmBwdDataV4R1Xdlops::GetSolution(
                 std::string(" -DCK_USE_AMD_XDLOPS_INLINE_ASM=") + (env::enabled(MIOPEN_DEBUG_IMPLICIT_GEMM_XDLOPS_INLINE_ASM) ? '1' : '0') +
                 std::string(" -DCK_USE_AMD_XDLOPS_EMULATE=") + (env::enabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_XDLOPS_EMULATE) ? '1' : '0') +
                 std::string(" -DCK_PARAM_GEMM_ID=") + std::to_string(gemm_id) +
+#if HIP_PACKAGE_VERSION_FLAT >= 6004000000
+                std::string(" -DCK_USE_AMD_BUFFER_PTR_TYPE=1") +
+#endif
                 static_ck::get_static_ck_common_compiler_flag(ctx) +
-                ctx.general_compile_options;
+                ctx.general_compile_options + " --std=c++17";
 
                 construction_parameters.comp_options +=
                     std::string(" -DCK_PARAM_KPACK_LENGTH=") + std::to_string(pcfg->GemmKPACKSize) +
