@@ -36,6 +36,9 @@
 
 #include <algorithm>
 
+// LWPMIOPEN-1392: Disabling failing deprecated Ocl solvers for Gfx11 and Gfx12
+#define WORKAROUND_LWPMIOPEN_1392 (HIP_PACKAGE_VERSION_FLAT >= 6004000000)
+
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_CONV_DIRECT_OCL_WRW2_SEARCH_OPTIMIZED)
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_CONV_DIRECT_OCL_WRW2)
 
@@ -135,7 +138,7 @@ inline static bool Inc_2_to_11_optimized(int& v)
 // in issue 1289
 #define WORKAROUND_ISSUE_1185 1
 
-static bool IsTunable(const ProblemDescription& problem)
+static bool IsTunableBase(const ProblemDescription& problem)
 {
     return !(problem.GetGroupCount() == 1 &&
              ((problem.GetWeightsWidth() == 3 && problem.GetWeightsHeight() == 3) ||
@@ -149,7 +152,7 @@ bool ConvOclBwdWrW2NonTunable::IsApplicable(const ExecutionContext& ctx,
     // reasons: after tuning ocl kernel for 3x3 and 1x1 filters, assembly kernel still
     // dominates. Thus, this solver is used for non-group 3x3 and 1x1 filters only.
     const auto tunable = ConvOclBwdWrW2<1>{};
-    return tunable.IsApplicableBase(ctx, problem) && !IsTunable(problem);
+    return tunable.IsApplicableBase(ctx, problem) && !IsTunableBase(problem);
 }
 
 size_t ConvOclBwdWrW2NonTunable::GetWorkspaceSize(const ExecutionContext& ctx,
@@ -461,6 +464,18 @@ template <int N_BATCH_LOOPS>
 bool ConvOclBwdWrW2<N_BATCH_LOOPS>::IsApplicableBase(const ExecutionContext& ctx,
                                                      const ProblemDescription& problem) const
 {
+    // Disable this solver due to random GPU memory access faults on gfx11 and gfx12
+#if WORKAROUND_LWPMIOPEN_1392
+    {
+        const auto device = ctx.GetStream().GetTargetProperties().Name();
+        if(miopen::StartsWith(device, "gfx11") || miopen::StartsWith(device, "gfx12"))
+        {
+            if(!env::enabled(MIOPEN_DEBUG_CONV_DIRECT_OCL_WRW2))
+                return false;
+        }
+    }
+#endif
+
     if(env::disabled(MIOPEN_DEBUG_CONV_DIRECT_OCL_WRW2))
         return false;
     if(ThisSolverIsDeprecatedStatic::IsDisabled(ctx))
@@ -520,7 +535,7 @@ template <int N_BATCH_LOOPS>
 bool ConvOclBwdWrW2<N_BATCH_LOOPS>::IsApplicable(const ExecutionContext& ctx,
                                                  const ProblemDescription& problem) const
 {
-    return IsApplicableBase(ctx, problem) && IsTunable(problem);
+    return IsApplicableBase(ctx, problem) && IsTunableBase(problem);
 }
 
 template <int N_BATCH_LOOPS>
