@@ -68,6 +68,11 @@ ConvOclDirectFwdFused::Search(const FusionContext& context,
 bool ConvOclDirectFwdFused::IsApplicable(const FusionContext& context,
                                          const FusionDescription& problem) const
 {
+    if(IsCKFusionSolverApplicable(context, problem))
+    {
+        return false;
+    }
+
     const auto& desc = *problem.fusion_plan_desc;
     if(desc.op_map.empty())
     {
@@ -171,11 +176,6 @@ ConvOclDirectFwdFused::GetSolution(const FusionContext& context,
     }
     kernel_info.comp_options += " " + build_params.GenerateFor(kbp::OpenCL{});
 
-    if(bn_idx != -1)
-        result.weight = 0.0f;
-    else
-        result.weight = 10.0f;
-
     result.invoker_factory = [=](const std::vector<Kernel>& kernels) {
         return [=](const Handle& handle, const AnyInvokeParams& primitive_parameters) {
             const auto& kernel = handle.Run(kernels[0]);
@@ -228,6 +228,18 @@ ConvOclDirectFwdFused::GetSolution(const FusionContext& context,
     return result;
 }
 
+float ConvOclDirectFwdFused::GetWti(const FusionContext&, const FusionDescription& problem) const
+{
+    /// \ref Negative WTI values
+
+    const auto& desc = *problem.fusion_plan_desc;
+    const int bn_idx = GetOpIdx(desc.op_map, miopenFusionOpBatchNormInference);
+    if(bn_idx != -1)
+        return wti_approximate_worst;
+    else
+        return wti_approximate_worst * .45f;
+}
+
 PerformanceConfigConvOclDirectFwdFused
 ConvOclDirectFwdFused::GetDefaultPerformanceConfig(const FusionContext& context,
                                                    const FusionDescription& problem) const
