@@ -183,7 +183,7 @@ struct test_driver
         return arguments.at(argument_index.at(s));
     }
 
-    bool has_argument(const std::string& arg) const { return argument_index.count(arg) > 0; }
+    bool has_argument(const std::string& arg) const { return argument_index.contains(arg); }
 
     template <class Visitor>
     void parse(Visitor v)
@@ -1041,7 +1041,7 @@ void check_unparsed_args(Driver& d,
                 std::cerr << "    " << s << std::endl;
             std::abort();
         }
-        else if(keywords.count(p.first) == 0)
+        else if(!keywords.contains(p.first))
         {
             assert(p.first.length() > 2);
             auto name = p.first.substr(2);
@@ -1244,8 +1244,7 @@ void test_drive_impl_1(std::string program_name, std::vector<std::string> as)
         "--help", "-h", "--half", "--float", "--double", "--int8", "--bfloat16"};
     d.parse(keyword_set{keywords});
     auto arg_map = args::parse(as, [&](std::string x) {
-        return (keywords.count(x) > 0) or
-               ((x.compare(0, 2, "--") == 0) and d.has_argument(x.substr(2)));
+        return (keywords.contains(x)) or ((x.starts_with("--")) and d.has_argument(x.substr(2)));
     });
 
     if(arg_map.count("--half") > 0)
