@@ -1,3 +1,6 @@
+// Copyright © Advanced Micro Devices, Inc., or its affiliates.
+// SPDX-License-Identifier:  MIT
+
 #include <iostream>
 #include <limits>
 
@@ -142,26 +145,27 @@ void testDumpWithNan(const std::string& test_file_name)
     fs::remove(test_file_name);
 }
 
-TEST(CPU_Dump_FP32, testDump) { testDump<float>(test_file_name_prefix + "float.bin"); }
-
-TEST(CPU_Dump_NAN_FP32, testDump)
+namespace {
+std::string GetFullFileName(const std::string& filename)
 {
-    testDumpWithNan<float>(test_file_name_prefix + "nan_float.bin");
+    return fs::temp_directory_path().append(test_file_name_prefix + filename).string();
 }
+} // namespace
 
-TEST(CPU_Dump_FP16, testDump)
-{
-    testDump<half_float::half>(test_file_name_prefix + "half_float.bin");
-}
+TEST(CPU_Dump_FP32, testDump) { testDump<float>(GetFullFileName("float.bin")); }
+
+TEST(CPU_Dump_NAN_FP32, testDump) { testDumpWithNan<float>(GetFullFileName("nan_float.bin")); }
+
+TEST(CPU_Dump_FP16, testDump) { testDump<half_float::half>(GetFullFileName("half_float.bin")); }
 
 TEST(CPU_Dump_NAN_FP16, testDump)
 {
-    testDumpWithNan<half_float::half>(test_file_name_prefix + "nan_half_float.bin");
+    testDumpWithNan<half_float::half>(GetFullFileName("nan_half_float.bin"));
 }
 
-TEST(CPU_Dump_BFP16, testDump) { testDump<bfloat16>(test_file_name_prefix + "bfloat16.bin"); }
+TEST(CPU_Dump_BFP16, testDump) { testDump<bfloat16>(GetFullFileName("bfloat16.bin")); }
 
 TEST(CPU_Dump_NAN_BFP16, testDump)
 {
-    testDumpWithNan<bfloat16>(test_file_name_prefix + "nan_bfloat16.bin");
+    testDumpWithNan<bfloat16>(GetFullFileName("nan_bfloat16.bin"));
 }
