@@ -27,8 +27,7 @@
 #include <gtest/gtest.h>
 #include <miopen/env.hpp>
 #include "get_handle.hpp"
-#include "test_env.hpp"
-
+#include "gtest_common.hpp"
 #include "pooling2d.hpp"
 
 MIOPEN_DECLARE_ENV_VAR_STR(MIOPEN_TEST_FLAGS_ARGS)
@@ -37,12 +36,14 @@ namespace env = miopen::env;
 
 namespace pooling2d_wide {
 
-class GPU_Pooling2d_FP32 : public testing::TestWithParam<std::vector<std::string>>
+class GPU_WidePooling2d_FP32 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 
 class GPU_WidePooling2d_FP16 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 
 void GetArgs(const std::string& param, std::vector<std::string>& tokens)
@@ -60,21 +61,21 @@ void Run2dDriver(miopenDataType_t prec)
     std::vector<std::string> params;
     switch(prec)
     {
-    case miopenFloat: params = GPU_Pooling2d_FP32::GetParam(); break;
+    case miopenFloat: params = GPU_WidePooling2d_FP32::GetParam(); break;
     case miopenHalf: params = GPU_WidePooling2d_FP16::GetParam(); break;
     case miopenBFloat16:
     case miopenInt8:
-    case miopenFloat8:
-    case miopenBFloat8:
+    case miopenFloat8_fnuz:
+    case miopenBFloat8_fnuz:
     case miopenInt32:
     case miopenInt64:
     case miopenDouble:
-        FAIL()
-            << "miopenBFloat16, miopenInt8, miopenInt32, miopenDouble, miopenFloat8, miopenBFloat8 "
-               "data type not supported by "
-               "immed_conv2d_codecov test";
+        FAIL() << "miopenBFloat16, miopenInt8, miopenInt32, miopenDouble, miopenFloat8_fnuz, "
+                  "miopenBFloat8_fnuz "
+                  "data type not supported by "
+                  "pooling2d_wide test";
 
-    default: params = GPU_Pooling2d_FP32::GetParam();
+    default: params = GPU_WidePooling2d_FP32::GetParam();
     }
 
     for(const auto& test_value : params)
@@ -113,10 +114,10 @@ std::vector<std::string> GetTestCases(const std::string& precision)
 using namespace pooling2d_wide;
 
 /*
-TEST_P(GPU_Pooling2d_FP32, FloatTest_pooling2d_wide)
+TEST_P(GPU_WidePooling2d_FP32, FloatTest_pooling2d_wide)
 {
     const auto& handle = get_handle();
-    if(IsTestSupportedForDevice(handle) && !SkipTest() && IsTestRunWith("--float"))
+    if(IsTestSupportedForDevice(handle))
     {
         Run2dDriver(miopenFloat);
     }
@@ -140,6 +141,6 @@ TEST_P(GPU_WidePooling2d_FP16, HalfTest_pooling2d_wide)
     }
 };
 
-// INSTANTIATE_TEST_SUITE_P(Full, GPU_Pooling2d_FP32, testing::Values(GetTestCases("--float")));
+// INSTANTIATE_TEST_SUITE_P(Full, GPU_WidePooling2d_FP32, testing::Values(GetTestCases("--float")));
 
 INSTANTIATE_TEST_SUITE_P(Full, GPU_WidePooling2d_FP16, testing::Values(GetTestCases("--half")));
